<?php
/**
 * Plugin cid : Fonctions diverses
 * Copyright (c) Christophe IMBERTI
 * Licence Creative commons by-nc-sa
 */

if (!defined("_ECRIRE_INC_VERSION")) return;

/**
 * Pour eviter que le calcul des rubriques depublie
 * une rubrique publiee directement sans objet publie
 */
function cid_calculer_rubriques($arg) {
	// SPIP permet a des plugins de gerer le statut autrement
	// (par ex: toute rubrique est publiee des sa creation)
	// si le plugin veut modifier les statuts/dates
	// c'est statut_tmp/date_tmp qu'il doit modifier
	if (!defined('_DIR_PLUGIN_CIPUBRUB'))	
		sql_updateq('spip_rubriques', array('statut_tmp'=>'publie'), "statut='publie' AND date='0000-00-00 00:00:00'");
	return true;
}


/**
 * Dans l'espace prive, afficher le bloc de statut pour une rubrique
 *
 * @param 	$flux
 * @return 	$flux
 */
function cid_boite_infos(&$flux){
	if (!defined('_DIR_PLUGIN_CIPUBRUB')) {	
		if (spip_version()>=3) {

		} else {
			$objet = $flux['args']['type'];
			$id_objet = intval($flux['args']['id']);
			$statut = $flux['args']['row']['statut'];
		
			if ($objet=='rubrique' AND $id_objet) {
				$instituer_rubrique = charger_fonction('cid_rubrique', 'inc');
				$texte = $instituer_rubrique($id_objet, $statut);
		
				if ($pos = strpos($flux['data'],'</div>')){
					$flux['data'] = substr($flux['data'],0,$pos+6).$texte.substr($flux['data'],$pos+6);
				}
			}
		}
	}

	return $flux;
}


/**
 * Optimiser la base de donnee en supprimant les documents orphelins
 *
 * @param int $n
 * @return int
 */
function cid_optimiser_base_disparus($flux){

	// les liens de documents d'articles effaces
	$result = sql_select("lien.id_document AS id, lien.id_objet AS ido",
		    "spip_documents_liens AS lien LEFT JOIN spip_articles AS articles
		          ON lien.id_objet=articles.id_article",
			"lien.objet='article' AND articles.id_article IS NULL");

	// on dissocie
	while ($row = sql_fetch($result))
		sql_delete("spip_documents_liens", "id_document=".$row['id']." AND id_objet=".$row['ido']." AND objet='article'");



	// les liens de documents de rubriques effaces
	$result = sql_select("lien.id_document AS id, lien.id_objet AS ido",
		    "spip_documents_liens AS lien LEFT JOIN spip_rubriques AS rubriques
		          ON lien.id_objet=rubriques.id_rubrique",
			"lien.objet='rubrique' AND rubriques.id_rubrique IS NULL");

	// on dissocie
	while ($row = sql_fetch($result))
		sql_delete("spip_documents_liens", "id_document=".$row['id']." AND id_objet=".$row['ido']." AND objet='rubrique'");



	// les documents sans liens
      	if (spip_version()>=3)
            $result = sql_select("doc.id_document AS id",
		    "spip_documents AS doc LEFT JOIN spip_documents_liens AS lien
		          ON doc.id_document=lien.id_document",
			"doc.mode<>'vignette' AND lien.id_document IS NULL");
        else
            $result = sql_select("doc.id_document AS id",
		    "spip_documents AS doc LEFT JOIN spip_documents_liens AS lien
		          ON doc.id_document=lien.id_document",
			"lien.id_document IS NULL");

    $documents = array();
	while ($row = sql_fetch($result))
		$documents[] = $row['id'];
		
	sql_free($result);
	
	
	// On supprime chaque document sans liens
	foreach($documents AS $id_document)
		cid_supprimer_document($id_document);


    return $flux;
}	


function cid_supprimer_document($id_document) {

	include_spip('inc/documents');
	if (!$doc = sql_fetsel('*', 'spip_documents', 'id_document='.$id_document))
		return false;

	spip_log("Suppression du document $id_document (".$doc['fichier'].")");

	// Si c'est un document ayant une vignette, supprimer aussi la vignette
	if ($doc['id_vignette']) {
		cid_supprimer_document($doc['id_vignette']);
		sql_delete('spip_documents_liens', 'id_document='.$doc['id_vignette']);
	}

	// Supprimer le fichier si le doc est local,
	// et la copie locale si le doc est distant
	if ($doc['distant'] == 'oui') {
		include_spip('inc/distant');
		if ($local = copie_locale($doc['fichier'],'test'))
			spip_unlink($local);
	}
	else spip_unlink(get_spip_doc($doc['fichier']));

	sql_delete('spip_documents', 'id_document='.$id_document);

	if (defined('_DIR_PLUGIN_CITRACE')){
		$message = '('.$doc['fichier'].')';		
		if ($citrace = charger_fonction('citrace', 'inc'))
			$citrace('document', $id_document, 'supprimer document', $message);
	}

	return true;
}

/**
 * Ajoute un bloc dans la page naviguer
 *
 * @param array
 * @return array
 */
function cid_affiche_gauche($flux) {
    $exec = $flux["args"]["exec"];

    if (!defined('_DIR_PLUGIN_VIDER_RUBRIQUE')){
        
        $javascript = " onclick=\"return confirm('"._T('cid:confirm_vider_rubrique')."');\" ";
        
	if (spip_version()>=3) {
		include_spip('inc/presentation');
		include_spip('inc/filtres_boites');
				
		if ($en_cours = trouver_objet_exec($flux['args']['exec']) AND $en_cours['type']=='rubrique'){
                    $id_rubrique = intval($flux["args"]["id_rubrique"]);
                    if ($id_rubrique){
                        // Si on a le droit de modifier cette rubrique et qu'elle ne contient pas de sous rubrique
                        if (autoriser('modifier', 'rubrique', $id_rubrique) 
                                AND !sql_countsel("spip_rubriques", "id_parent=".intval($id_rubrique))){
                            
                            $url = generer_action_auteur("cid_vider", $id_rubrique, self());
                            $ret = boite_ouvrir('', 'raccourcis');
                            $ret .= icone_base($url, _T('cid:vider_rubrique'), "cid_article.png", "del", "horizontale", $javascript);
                            $ret .= boite_fermer();
                            if ($p=strpos($flux['data'],"<!--affiche_milieu-->"))
                                    $flux['data'] = substr_replace($flux['data'],$ret,$p,0);
                            else
                                    $flux["data"] .= $ret;
                        }
                    }
		}
		
	} else {
	
		if ($exec=="naviguer") {
                    $id_rubrique = intval($flux["args"]["id_rubrique"]);
                    if ($id_rubrique){
                        if (autoriser('modifier', 'rubrique', $id_rubrique) 
                                AND !sql_countsel("spip_rubriques", "id_parent=".intval($id_rubrique))){
                            $url = generer_action_auteur("cid_vider", $id_rubrique, self());
                            $ret = icone_horizontale(_T('cid:vider_rubrique'), $url, chemin("images/cid_article.png"), "supprimer.gif", false, $javascript);
                            $flux["data"] .= bloc_des_raccourcis($ret);
                        }
                    }
		}
	}
    }
    return $flux;
}

?>